==> operation-prime-2.0.2-20140325.162951-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/DuplicateRowValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AnnotationColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AttributeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeDescriptionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeNameColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.DimensionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.MeasureColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.TimeDimensionColumnType;
import org.gcube.data.analysis.tabulardata.model.table.TableType;
import org.gcube.data.analysis.tabulardata.model.table.type.CodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.DatasetTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.GenericTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.HierarchicalCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.TableValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.TargetColumnParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class DuplicateRowValidatorFactory extends TableValidatorFactory {

	private static final List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5003);
	
	private CubeManager cubeManager;

	private DatabaseConnectionProvider connectionProvider;

	public static TargetColumnParameter KEY;
	
	static{
		ArrayList<TableType> allowedTableTypes=new ArrayList<>();
		ArrayList<ColumnType> allowedColumnTypes=new ArrayList<>();
		
		
		allowedTableTypes.add(new CodelistTableType());
		allowedTableTypes.add(new GenericTableType());
		allowedTableTypes.add(new DatasetTableType());
		allowedTableTypes.add(new HierarchicalCodelistTableType());
		allowedTableTypes.add(new TimeCodelistTableType());
		
		allowedColumnTypes.add(new AnnotationColumnType());
		allowedColumnTypes.add(new AttributeColumnType());
		allowedColumnTypes.add(new CodeColumnType());
		allowedColumnTypes.add(new CodeDescriptionColumnType());
		allowedColumnTypes.add(new CodeNameColumnType());
		allowedColumnTypes.add(new DimensionColumnType());
		allowedColumnTypes.add(new MeasureColumnType());
		allowedColumnTypes.add(new TimeDimensionColumnType());
		
		KEY=new TargetColumnParameter("key", "Key", "To check uniqueness column", 
				new Cardinality(0, Integer.MAX_VALUE),allowedTableTypes, allowedColumnTypes);		
		
		parameters.add(KEY);
	}
	
	@Inject
	public DuplicateRowValidatorFactory(CubeManager cubeManager, DatabaseConnectionProvider connectionProvider) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		return new DuplicateRowValidator(invocation, cubeManager, connectionProvider);
	}

	@Override
	protected String getOperationName() {
		return "Duplicate tuple validation";
	}

	@Override
	protected String getOperationDescription() {
		return "Check for duplicate tuples in table";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}

==> operation-prime-2.0.7-20140408.133542-3-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/DuplicateRowValidatorFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.expression.evaluator.sql.SQLExpressionEvaluatorFactory;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AnnotationColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AttributeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeDescriptionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeNameColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.DimensionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.MeasureColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.TimeDimensionColumnType;
import org.gcube.data.analysis.tabulardata.model.table.TableType;
import org.gcube.data.analysis.tabulardata.model.table.type.CodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.DatasetTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.GenericTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.HierarchicalCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.operation.OperationId;
import org.gcube.data.analysis.tabulardata.operation.factories.types.TableValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Cardinality;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.parameters.leaves.TargetColumnParameter;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

@Singleton
public class DuplicateRowValidatorFactory extends TableValidatorFactory {

	private static final List<Parameter> parameters = new ArrayList<Parameter>();
	
	private static final OperationId OPERATION_ID = new OperationId(5003);
	
	private CubeManager cubeManager;

	private DatabaseConnectionProvider connectionProvider;
	private SQLExpressionEvaluatorFactory evaluatorFactory;
	
	public static TargetColumnParameter KEY;
	
	static{
		ArrayList<TableType> allowedTableTypes=new ArrayList<>();
		ArrayList<ColumnType> allowedColumnTypes=new ArrayList<>();
		
		
		allowedTableTypes.add(new CodelistTableType());
		allowedTableTypes.add(new GenericTableType());
		allowedTableTypes.add(new DatasetTableType());
		allowedTableTypes.add(new HierarchicalCodelistTableType());
		allowedTableTypes.add(new TimeCodelistTableType());
		
		allowedColumnTypes.add(new AnnotationColumnType());
		allowedColumnTypes.add(new AttributeColumnType());
		allowedColumnTypes.add(new CodeColumnType());
		allowedColumnTypes.add(new CodeDescriptionColumnType());
		allowedColumnTypes.add(new CodeNameColumnType());
		allowedColumnTypes.add(new DimensionColumnType());
		allowedColumnTypes.add(new MeasureColumnType());
		allowedColumnTypes.add(new TimeDimensionColumnType());
		
		KEY=new TargetColumnParameter("key", "Key", "To check uniqueness column", 
				new Cardinality(0, Integer.MAX_VALUE),allowedTableTypes, allowedColumnTypes);		
		
		parameters.add(KEY);
	}
	
	@Inject
	public DuplicateRowValidatorFactory(CubeManager cubeManager, DatabaseConnectionProvider connectionProvider,SQLExpressionEvaluatorFactory factory) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
		this.evaluatorFactory=factory;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		return new DuplicateRowValidator(invocation, cubeManager, connectionProvider,evaluatorFactory);
	}

	@Override
	protected String getOperationName() {
		return "Duplicate tuple validation";
	}

	@Override
	protected String getOperationDescription() {
		return "Check for duplicate tuples in table";
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}

	@Override
	protected OperationId getOperationId() {
		return OPERATION_ID;
	}
	
}
